==> odoo12-addon-somconnexio-12.0.1.8.1.tar.gz: odoo12-addon-somconnexio-12.0.1.8.1/odoo/addons/somconnexio/__manifest__.py <==
{
    'name': "Odoo Som Connexió customizations",
    'version': '12.0.1.8.1',
    'depends': [
        'account_asset_management',
        'account_banking_sepa_credit_transfer',
        'account_banking_sepa_direct_debit',
        'account_cancel',
        'account_chart_update',
        'account_due_list',
        'account_financial_report',
        'account_invoice_validation_queued',
        'account_payment_mode',
        'account_payment_order',
        'account_payment_partner',
        'account_payment_return',
        'account_payment_return_import_iso20022',
        'base_automation',
        'base_import_async',
        'check_concurrent_update',
        'component_event',
        'contract',
        'contract_mandate',
        'contract_payment_mode',
        'crm_lead_product',
        'easy_my_coop_api',
        'easy_my_coop_es',
        'easy_my_coop_sponsorship',
        'hr',
        'hr_attendance',
        'hr_attendance_report_theoretical_time',
        'hr_contract',
        'hr_holidays',
        'hr_holidays_leave_auto_approve',
        'hr_holidays_public',
        'hr_timesheet',
        'l10n_es',
        'l10n_es_account_asset',
        'l10n_es_account_bank_statement_import_n43',
        'l10n_es_aeat',
        'l10n_es_aeat_mod111',
        'l10n_es_aeat_mod190',
        'l10n_es_aeat_mod303',
        'l10n_es_aeat_mod349',
        'l10n_es_aeat_mod390',
        'l10n_es_mis_report',
        'l10n_es_partner',
        'mail',
        'mail_activity_board',
        'mail_activity_done',
        'mass_editing',
        'mass_mailing_list_dynamic',
        'mis_builder',
        'mis_builder_budget',
        'partner_firstname',
        'partner_priority',
        'account_payment_return_import',
        'queue_job',
        'sale_management',
        'stock',
        'web_decimal_numpad_dot',
        'web_favicon',
        'web_m2x_options',
        'web_no_bubble',
        'web_responsive',
        'web_searchbar_full_width',
        'web_widget_open_tab',
    ],
    'external_dependencies': {
        'python': [
            'otrs_somconnexio',
            'faker',
            'pyopencell',
            'factory',
            'stdnum',
        ],
    },
    'author': "Coopdevs Treball SCCL",
    'website': 'https://coopdevs.org',
    'category': "Cooperative management",
    "license": "AGPL-3",
    'data': [
        'data/product_categories.xml',
        'views/account_invoice_view.xml',
        'views/subscription_request_view.xml',
        'views/coop_agreement_view.xml',
        'views/res_partner_view.xml',
        'security/res_groups.xml',
        'data/service_supplier.xml',
        'views/contract_view.xml',
        'views/service_technology_service_supplier.xml',
        'views/product_pricelist_view.xml',
        'views/product_category_technology_supplier_view.xml',
        'views/previous_provider_view.xml',
        'views/crm_lead_line.xml',
        'views/menus.xml',
        'views/crm_lead.xml',
        'views/hr_attendance.xml',
        'views/mobile_isp_info_view.xml',
        'views/broadband_isp_info_view.xml',
        'views/stock_move_line_view.xml',
        'views/stock_production_lot.xml',
        'views/mis_budget_item_view.xml',
        'views/mobile_service_contract_info_view.xml',
        'views/adsl_service_contract_info_view.xml',
        'views/vodafone_fiber_service_contract_info.xml',
        'views/mm_fiber_service_contract_info.xml',
        'views/operation_request.xml',
        'views/product_template_view.xml',
        'views/product_product_view.xml',
        'views/product_attribute_views.xml',
        'views/router_4G_service_contract_info.xml',
        'views/res_company_view.xml',
        'views/account_payment_order_view.xml',
        'security/ir.model.access.csv',
        'data/service_technology.xml',
        'data/service_technology_service_supplier.xml',
        'data/operation_request_terminate_reason.xml',
        'data/product_category_technology_supplier_data.xml',
        'data/product_attribute.xml',
        'data/product_attribute_value.xml',
        'data/product_product.xml',
        'data/product_template_attribute_line_data.xml',
        'data/product_template_data.xml',
        'data/account_chart_template_data.xml',
        'data/discovery_channel.xml',
        'data/account_group.xml',
        'data/account.account.template-sc.csv',
        'data/account_payment_term.xml',
        'data/company.xml',
        'data/contract_compute_current_tariff_cron.xml',
        'data/res.partner.bank.xml',
        'data/account_journal.xml',
        'data/account_payment_mode.xml',
        'data/mail_mass_mailing_list_data.xml',
        'data/ir_sequence.xml',
        'data/res.users.xml',
        'data/previous_provider_data.xml',
        'views/templates_js.xml',
        'data/ir_config_pararameter.xml',
        'data/contract_terminate_reason.xml',
        'data/contract_terminate_user_reason.xml',
        'data/fiber_signal_type_data.xml',
        'wizards/crm_leads_validate/crm_leads_validate.xml',
        'wizards/crm_lead_lines_validate/crm_lead_lines_validate.xml',
        'wizards/crm_lead_lines_remesa/crm_lead_lines_remesa.xml',
        'wizards/contract_force_oc_integration/contract_force_oc_integration.xml',
        'wizards/contract_iban_change/contract_iban_change.xml',
        'wizards/contract_holder_change/contract_holder_change.xml',
        'wizards/partner_email_change/partner_email_change.xml',
        'wizards/contract_address_change/contract_address_change.xml',
        'wizards/contract_one_shot_request/contract_one_shot_request.xml',
        'wizards/contract_tariff_change/contract_tariff_change.xml',
        'wizards/contract_terminate/contract_terminate.xml',
        'wizards/move_line_add_to_payment_debit_order/move_line_add_to_payment_debit_order.xml',  # noqa
        'wizards/create_lead_from_partner/create_lead_from_partner.xml',
        'wizards/partner_check_somoffice_email/partner_check_somoffice_email.xml',
        'wizards/payment_order_generated_to_uploaded_queued/payment_order_generated_to_uploaded_queued.xml', # noqa
        'wizards/account_financial_report/aged_partner_balance.xml',
        'data/share_type.xml',
        'data/res_bank_data.xml',
        'views/account_tax_view.xml',
        'views/account_tax_view.xml',
        'reports/report_paperformat.xml',
        'reports/sim_sending_letter_template.xml',
        'reports/new_sim_sending_letter_template.xml',
        'views/act_account_move_to_account_move_line_open.xml',
        'reports/aged_partner_balance.xml',
        'data/partner_priority.xml',
        'reports/invoice_claim_1_template.xml',
        'reports/invoice_claim_1_capital_template.xml',
        'data/mail_activity_type.xml',
        'views/mail_activity_view.xml',
        'views/open_boards_activities.xml',
        'wizards/invoice_claim_1_send/invoice_claim_1_send.xml',
        'data/account_tax_group.xml',
        'data/account_tax.xml',
        'data/mis_report.xml',
        'wizards/create_subscription_from_partner/create_subscription_from_partner.xml',
        'reports/crm_lead_line_creation_email_template.xml',
        'data/base_automation.xml',
        'wizards/contract_invoice_payment/contract_invoice_payment.xml',
        'views/account_move_line.xml',
        'views/ir_action_view.xml',
        'data/mail_data.xml',
        'wizards/import_payment_group/import_payment_group.xml',
        'views/payment_return_view.xml',
        'data/crm_stage_data.xml',
        'data/hr_attendance_place.xml',
        'views/payment_return_import_view.xml',
        'wizards/account_payment_line_create/account_payment_line_create_view.xml',
        'wizards/contract_compensation/contract_compensation.xml',
        'views/xoln_fiber_service_contract_info.xml',
        'data/analytic_account.xml',
        'wizards/product_publish/product_publish.xml',
        'views/orange_fiber_service_contract_info.xml'
    ],
    'demo': [
        'demo/partner.xml',
        'demo/pricelist.xml',
        'demo/subscription_requests.xml',
    ],
    'qweb': [
        'static/src/xml/activity.xml',
        'static/src/xml/attendance.xml',
        'static/src/xml/contract_email.xml',
        'static/src/xml/mail_chatter_buttons.xml',
    ],
    'post_load': "post_load_hook",
}

==> odoo12-addon-somconnexio-12.0.1.8.2.tar.gz: odoo12-addon-somconnexio-12.0.1.8.2/odoo/addons/somconnexio/__manifest__.py <==
{
    'name': "Odoo Som Connexió customizations",
    'version': '12.0.1.8.2',
    'depends': [
        'account_asset_management',
        'account_banking_sepa_credit_transfer',
        'account_banking_sepa_direct_debit',
        'account_cancel',
        'account_chart_update',
        'account_due_list',
        'account_financial_report',
        'account_invoice_validation_queued',
        'account_payment_mode',
        'account_payment_order',
        'account_payment_partner',
        'account_payment_return',
        'account_payment_return_import_iso20022',
        'base_automation',
        'base_import_async',
        'check_concurrent_update',
        'component_event',
        'contract',
        'contract_mandate',
        'contract_payment_mode',
        'crm_lead_product',
        'easy_my_coop_api',
        'easy_my_coop_es',
        'easy_my_coop_sponsorship',
        'hr',
        'hr_attendance',
        'hr_attendance_report_theoretical_time',
        'hr_contract',
        'hr_holidays',
        'hr_holidays_leave_auto_approve',
        'hr_holidays_public',
        'hr_timesheet',
        'l10n_es',
        'l10n_es_account_asset',
        'l10n_es_account_bank_statement_import_n43',
        'l10n_es_aeat',
        'l10n_es_aeat_mod111',
        'l10n_es_aeat_mod190',
        'l10n_es_aeat_mod303',
        'l10n_es_aeat_mod347',
        'l10n_es_aeat_mod349',
        'l10n_es_aeat_mod390',
        'l10n_es_mis_report',
        'l10n_es_partner',
        'mail',
        'mail_activity_board',
        'mail_activity_done',
        'mass_editing',
        'mass_mailing_list_dynamic',
        'mis_builder',
        'mis_builder_budget',
        'partner_firstname',
        'partner_priority',
        'account_payment_return_import',
        'queue_job',
        'sale_management',
        'stock',
        'web_decimal_numpad_dot',
        'web_favicon',
        'web_m2x_options',
        'web_no_bubble',
        'web_responsive',
        'web_searchbar_full_width',
        'web_widget_open_tab',
    ],
    'external_dependencies': {
        'python': [
            'otrs_somconnexio',
            'faker',
            'pyopencell',
            'factory',
            'stdnum',
        ],
    },
    'author': "Coopdevs Treball SCCL",
    'website': 'https://coopdevs.org',
    'category': "Cooperative management",
    "license": "AGPL-3",
    'data': [
        'data/product_categories.xml',
        'views/account_invoice_view.xml',
        'views/subscription_request_view.xml',
        'views/coop_agreement_view.xml',
        'views/res_partner_view.xml',
        'security/res_groups.xml',
        'data/service_supplier.xml',
        'views/contract_view.xml',
        'views/service_technology_service_supplier.xml',
        'views/product_pricelist_view.xml',
        'views/product_category_technology_supplier_view.xml',
        'views/previous_provider_view.xml',
        'views/crm_lead_line.xml',
        'views/menus.xml',
        'views/crm_lead.xml',
        'views/hr_attendance.xml',
        'views/mobile_isp_info_view.xml',
        'views/broadband_isp_info_view.xml',
        'views/stock_move_line_view.xml',
        'views/stock_production_lot.xml',
        'views/mis_budget_item_view.xml',
        'views/mobile_service_contract_info_view.xml',
        'views/adsl_service_contract_info_view.xml',
        'views/vodafone_fiber_service_contract_info.xml',
        'views/mm_fiber_service_contract_info.xml',
        'views/operation_request.xml',
        'views/product_template_view.xml',
        'views/product_product_view.xml',
        'views/product_attribute_views.xml',
        'views/router_4G_service_contract_info.xml',
        'views/res_company_view.xml',
        'views/account_payment_order_view.xml',
        'security/ir.model.access.csv',
        'data/service_technology.xml',
        'data/service_technology_service_supplier.xml',
        'data/operation_request_terminate_reason.xml',
        'data/product_category_technology_supplier_data.xml',
        'data/product_attribute.xml',
        'data/product_attribute_value.xml',
        'data/product_product.xml',
        'data/product_template_attribute_line_data.xml',
        'data/product_template_data.xml',
        'data/account_chart_template_data.xml',
        'data/discovery_channel.xml',
        'data/account_group.xml',
        'data/account.account.template-sc.csv',
        'data/account_payment_term.xml',
        'data/company.xml',
        'data/contract_compute_current_tariff_cron.xml',
        'data/res.partner.bank.xml',
        'data/account_journal.xml',
        'data/account_payment_mode.xml',
        'data/mail_mass_mailing_list_data.xml',
        'data/ir_sequence.xml',
        'data/res.users.xml',
        'data/previous_provider_data.xml',
        'views/templates_js.xml',
        'data/ir_config_pararameter.xml',
        'data/contract_terminate_reason.xml',
        'data/contract_terminate_user_reason.xml',
        'data/fiber_signal_type_data.xml',
        'wizards/crm_leads_validate/crm_leads_validate.xml',
        'wizards/crm_lead_lines_validate/crm_lead_lines_validate.xml',
        'wizards/crm_lead_lines_remesa/crm_lead_lines_remesa.xml',
        'wizards/contract_force_oc_integration/contract_force_oc_integration.xml',
        'wizards/contract_iban_change/contract_iban_change.xml',
        'wizards/contract_holder_change/contract_holder_change.xml',
        'wizards/partner_email_change/partner_email_change.xml',
        'wizards/contract_address_change/contract_address_change.xml',
        'wizards/contract_one_shot_request/contract_one_shot_request.xml',
        'wizards/contract_tariff_change/contract_tariff_change.xml',
        'wizards/contract_terminate/contract_terminate.xml',
        'wizards/move_line_add_to_payment_debit_order/move_line_add_to_payment_debit_order.xml',  # noqa
        'wizards/create_lead_from_partner/create_lead_from_partner.xml',
        'wizards/partner_check_somoffice_email/partner_check_somoffice_email.xml',
        'wizards/payment_order_generated_to_uploaded_queued/payment_order_generated_to_uploaded_queued.xml', # noqa
        'wizards/account_financial_report/aged_partner_balance.xml',
        'data/share_type.xml',
        'data/res_bank_data.xml',
        'views/account_tax_view.xml',
        'views/account_tax_view.xml',
        'reports/report_paperformat.xml',
        'reports/sim_sending_letter_template.xml',
        'reports/new_sim_sending_letter_template.xml',
        'views/act_account_move_to_account_move_line_open.xml',
        'reports/aged_partner_balance.xml',
        'data/partner_priority.xml',
        'reports/invoice_claim_1_template.xml',
        'reports/invoice_claim_1_capital_template.xml',
        'data/mail_activity_type.xml',
        'views/mail_activity_view.xml',
        'views/open_boards_activities.xml',
        'wizards/invoice_claim_1_send/invoice_claim_1_send.xml',
        'data/account_tax_group.xml',
        'data/account_tax.xml',
        'data/mis_report.xml',
        'wizards/create_subscription_from_partner/create_subscription_from_partner.xml',
        'reports/crm_lead_line_creation_email_template.xml',
        'data/base_automation.xml',
        'wizards/contract_invoice_payment/contract_invoice_payment.xml',
        'views/account_move_line.xml',
        'views/ir_action_view.xml',
        'data/mail_data.xml',
        'wizards/import_payment_group/import_payment_group.xml',
        'views/payment_return_view.xml',
        'data/crm_stage_data.xml',
        'data/hr_attendance_place.xml',
        'views/payment_return_import_view.xml',
        'wizards/account_payment_line_create/account_payment_line_create_view.xml',
        'wizards/contract_compensation/contract_compensation.xml',
        'views/xoln_fiber_service_contract_info.xml',
        'data/analytic_account.xml',
        'wizards/product_publish/product_publish.xml',
        'views/orange_fiber_service_contract_info.xml',
        'views/aeat_report_view.xml'
    ],
    'demo': [
        'demo/partner.xml',
        'demo/pricelist.xml',
        'demo/subscription_requests.xml',
    ],
    'qweb': [
        'static/src/xml/activity.xml',
        'static/src/xml/attendance.xml',
        'static/src/xml/contract_email.xml',
        'static/src/xml/mail_chatter_buttons.xml',
    ],
    'post_load': "post_load_hook",
}
